==> nip2_7.20.7.orig.tar.gz: nip2-7.20.7/src/preview.h <==
/* thumbnail widget
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_PREVIEW (preview_get_type())
#define PREVIEW( obj ) \
	(GTK_CHECK_CAST( (obj), TYPE_PREVIEW, Preview ))
#define PREVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_PREVIEW, PreviewClass ))
#define IS_PREVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_PREVIEW ))
#define IS_PREVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_PREVIEW ))

struct _Preview {
	Imagedisplay parent;

	char *filename;			/* The file we are trying to display */
	Conversion *conv;		/* Hold a ref to the convert object */
};

typedef struct _PreviewClass {
	ImagedisplayClass parent_class;

	/* My methods.
	 */
} PreviewClass;

GtkType preview_get_type( void );
Preview *preview_new( void );
gboolean preview_set_filename( Preview *preview, char *filename );

==> nip2_7.28.4.orig.tar.gz: nip2-7.28.4/src/preview.h <==
/* thumbnail widget
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_PREVIEW (preview_get_type())
#define PREVIEW( obj ) \
	(GTK_CHECK_CAST( (obj), TYPE_PREVIEW, Preview ))
#define PREVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_PREVIEW, PreviewClass ))
#define IS_PREVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_PREVIEW ))
#define IS_PREVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_PREVIEW ))

struct _Preview {
	Imagedisplay parent;

	char *filename;			/* The file we are trying to display */
	Conversion *conv;		/* Hold a ref to the convert object */
};

typedef struct _PreviewClass {
	ImagedisplayClass parent_class;

	/* My methods.
	 */
} PreviewClass;

GtkType preview_get_type( void );
Preview *preview_new( void );
void preview_set_filename( Preview *preview, char *filename );
